def generate_possible_names(official_name, nicknames):
	ret = []
	for x in nicknames:
		names = official_name.split(" ")
		names = names[1:]
		names = ' '. join(names)
		ret += [x + ' ' + names]

	return ret


from database_Management import open_Connection, find_Ticker

class Key_People:
	def __init__(self):
		self.conn, self.c = open_Connection("DB/Stocks.db")

	def entry(self, ticker):
		ticker = ticker.upper()
		ticker = (ticker, )
		results = find_Ticker(ticker, self.c)[0]
		ticker = results[0]
		company_Name = results[1]
		people = []
		for x in results[2:]:
			if x != 'NULL':
				people.append(x)
		return entry(ticker, company_Name, people)

class entry:
	def __init__(self, ticker, company_Name, people):
		self.key_People = people
		self.company_Name = company_Name
		self.ticker = ticker

def get_Key_People(ticker):
	ticker = ticker.upper()
	conn, c = open_Connection("DB/Stocks.db")
	ticker = (ticker, )
	try:
		results = find_Ticker(ticker, c)[0]
		ticker = results[0]
		company_Name = results[1]
		people = []
		for x in results[2:]:
			if x != 'NULL':
				people.append(x)
		conn.close()
		return people
	except:
		raise Exception("Company not found (reminder: search by ticker)")

def get_c_Name(ticker):
	ticker = ticker.upper()
	conn, c = open_Connection("DB/Stocks.db")
	ticker = (ticker, )
	try:
		results = find_Ticker(ticker, c)[0]
		ticker = results[0]
		company_Name = results[1]
		conn.close()
		return company_Name
	except:
		raise Exception("Company not found (reminder: search by ticker)")




import sqlite3

def create_table(c, table_name, cols, types):

	command = 'CREATE TABLE '
	command += table_name
	command += ' ('
	if (len(cols) != len(types) and len(types) != 1):
		raise Exception("len cols must be equal to len types")

	if len(types) == 1:
		types = types * len(cols)

	for x in range(len(cols)):
		if x != 0:
			command += ", "
		command += cols[x]
		command += " "
		command += types[x]
	command += ")"
	c.execute(command)

def find_ticker(ticker, c):
	ticker = [ticker]
	c.execute('SELECT * FROM stocks WHERE symbol=?', ticker)
	return c.fetchone()

def find_nicknames(name, c):
	name = [name.lower()]
	c.execute('SELECT * FROM nicknames WHERE name=?', name)
	prefilter = c.fetchone()
	if prefilter == None:
		return prefilter
	ret = []
	for x in prefilter:
		if x != 'NULL':
			ret.append(x)
	return ret


"""UPDATE dbo.xxx
SET Value = REPLACE(Value, '123\', '')
WHERE ID <=4"""

def add_ticker(entry, c):
	c.execute('INSERT INTO stocks VALUES (?,?,?,?,?,?,?,?)', entry)

def add_nicknames(entries, c):
	c.executemany('INSERT INTO nicknames VALUES (?,?,?,?,?)', entries)

def add_many_entry(entries, c):
	c.executemany('INSERT INTO stocks VALUES (?,?,?,?,?,?,?,?)', entries)

def open_connection(file):
	conn = sqlite3.connect(file)
	c = conn.cursor()
	return conn, c

def commit_close(conn):
	conn.commit()
	conn.close()


import os
import pkg_resources
import sqlite3
from .database_management import open_connection
from .database_management import find_ticker
from .generate_possible_names import generate_possible_names


class Company:
	def __init__(self, ticker):
		DB_FILE = pkg_resources.resource_filename('key_people', 'DB/Stocks.db')
		self.conn, self.c = open_connection(DB_FILE)
		NICKNAME_FILE = pkg_resources.resource_filename('key_people', 'DB/Nicknames.db')
		self.n_conn, self.n_c = open_connection(DB_FILE)
		self.terms = pop(ticker)

		

	def pop(self, c):
		ticker = ticker.upper()
		ticker = (ticker, )
		results = find_ticker(ticker, self.c)[0]
		ticker = results[0]
		company_name = results[1]
		people = []
		for x in results[2:]:
			if x != 'NULL':
				x = generate_possible_names(x, c)
				people.append(x)

		return {'ticker': ticker, 'company_name': company_name, 'key_people_nicknames': people}

def get_terms(ticker):
	NICKNAME_FILE = pkg_resources.resource_filename('key_people', 'DB/Nicknames.db')
	conn, c = open_connection(DB_FILE)

	ticker = ticker.upper()
	ticker = (ticker, )
	results = find_ticker(ticker, c)[0]
	ticker = results[0]
	company_name = results[1]
	people = []
	for x in results[2:]:
		if x != 'NULL':
			x = generate_possible_names(x, c)
			people.append(x)

	return {'ticker': ticker, 'company_name': company_name, 'key_people_nicknames': people}
	
def search_company_name(ticker):
	ticker = ticker.upper()
	DB_FILE = pkg_resources.resource_filename('key_people', 'DB/Stocks.db')
	conn, c = open_connection(DB_FILE)
	ticker = (ticker, )
	results = find_ticker(ticker, c)[0]
	company_name = results[1]
	conn.close()
	return company_name


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['key_people']

package_data = \
{'': ['*'], 'key_people': ['DB/*']}

setup_kwargs = {
    'name': 'key-people',
    'version': '0.91',
    'description': 'This is used to pull any of the key people from a company based off of the ticker. Currently NASDAQ and NYSE supported',
    'long_description': 'This package is used to pull key people from a company based on the ticker.\n\n\nfrom Key-People import get_Key_People, Key_People, get_c_Name\n\nlist_of_key_people = get_Key_People("AAPL")\ncompany_Name = get_c_Name("AAPL")\n\n#if you are doing multiple entries and want to make it quicker\ndb = Key_People()\n\nentry = db.entry("AAPL")\n\nentry.company_Name\nentry.key_People\nentry.ticker\n',
    'author': 'Henry Becket Trotter',
    'author_email': 'beckettrotter@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/BecketTrotter/Key_People',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
